function varargout = PixelsizeDialog(varargin)
% PIXELSIZEDIALOG M-file for PixelsizeDialog.fig
%      PIXELSIZEDIALOG by itself, creates a new PIXELSIZEDIALOG or raises the
%      existing singleton*.
%
%      H = PIXELSIZEDIALOG returns the handle to a new PIXELSIZEDIALOG or the handle to
%      the existing singleton*.
%
%      PIXELSIZEDIALOG('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in PIXELSIZEDIALOG.M with the given input arguments.
%
%      PIXELSIZEDIALOG('Property','Value',...) creates a new PIXELSIZEDIALOG or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before PixelsizeDialog_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to PixelsizeDialog_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help PixelsizeDialog

% Last Modified by GUIDE v2.5 07-Aug-2005 19:47:24

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @PixelsizeDialog_OpeningFcn, ...
                   'gui_OutputFcn',  @PixelsizeDialog_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT

% --- Executes just before PixelsizeDialog is made visible.
function PixelsizeDialog_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to PixelsizeDialog (see VARARGIN)


handles.current.pixelsize  = varargin{1};


handles.pixelsize  = handles.current.pixelsize;



guidata(hObject, handles);

init_dialog(hObject, eventdata, handles, varargin);

% Choose default command line output for PixelsizeDialog
% handles.output = 'Yes';

% Update handles structure
% guidata(hObject, handles);

% Insert custom Title and Text if specified by the user
% Hint: when choosing keywords, be sure they are not easily confused 
% with existing figure properties.  See the output of set(figure) for
% a list of figure properties.
% if(nargin > 3)
%     for index = 1:2:(nargin-3),
%         if nargin-3==index, break, end
%         switch lower(varargin{index})
%          case 'title'
%           set(hObject, 'Name', varargin{index+1});
%          case 'string'
%           set(handles.text1, 'String', varargin{index+1});
%         end
%     end
% end

% Determine the position of the dialog - centered on the callback figure
% if available, else, centered on the screen
FigPos=get(0,'DefaultFigurePosition');
OldUnits = get(hObject, 'Units');
set(hObject, 'Units', 'pixels');
OldPos = get(hObject,'Position');
FigWidth = OldPos(3);
FigHeight = OldPos(4);
if isempty(gcbf)
    ScreenUnits=get(0,'Units');
    set(0,'Units','pixels');
    ScreenSize=get(0,'ScreenSize');
    set(0,'Units',ScreenUnits);

    FigPos(1)=1/2*(ScreenSize(3)-FigWidth);
    FigPos(2)=2/3*(ScreenSize(4)-FigHeight);
else
    GCBFOldUnits = get(gcbf,'Units');
    set(gcbf,'Units','pixels');
    GCBFPos = get(gcbf,'Position');
    set(gcbf,'Units',GCBFOldUnits);
    FigPos(1:2) = [(GCBFPos(1) + GCBFPos(3) / 2) - FigWidth / 2, ...
                   (GCBFPos(2) + GCBFPos(4) / 2) - FigHeight / 2];
end
FigPos(3:4)=[FigWidth FigHeight];
set(hObject, 'Position', FigPos);
set(hObject, 'Units', OldUnits);



% Make the GUI modal
set(handles.figure1,'WindowStyle','modal')

% UIWAIT makes PixelsizeDialog wait for user response (see UIRESUME)
uiwait(handles.figure1);

% --- Outputs from this function are returned to the command line.
function varargout = PixelsizeDialog_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.current.pixelsize;
varargout{2} = handles.rescale;


% The figure can be deleted now
delete(handles.figure1);

% --- Executes on button press in OkButton.
function OkButton_Callback(hObject, eventdata, handles)
% hObject    handle to OkButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

handles.current.pixelsize  = handles.pixelsize             ;

guidata(hObject, handles);

% Use UIRESUME instead of delete because the OutputFcn needs
% to get the updated handles structure.
uiresume(handles.figure1);




% --- Executes on button press in CancelButton.
function CancelButton_Callback(hObject, eventdata, handles)
% hObject    handle to CancelButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

uiresume(handles.figure1);






function PixelsizeEdit_Callback(hObject, eventdata, handles)
% hObject    handle to ChooseRangeMaxEdit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of ChooseRangeMaxEdit as text
%        str2double(get(hObject,'String')) returns contents of ChooseRangeMaxEdit as a double



pixelsize = str2double(get(hObject, 'String'));
if isnan(pixelsize)
    errordlg('Input must be a number','Error');
    set(handles.PixelsizeEdit,        'String',sprintf('%g',  handles.pixelsize));
else
    handles.pixelsize = pixelsize;
    guidata(hObject, handles);
    set(handles.PixelsizeEdit,        'String',sprintf('%g',  handles.pixelsize));
end;


% --- Executes during object creation, after setting all properties.
function PixelsizeEdit_CreateFcn(hObject, eventdata, handles)
% hObject    handle to ChooseRangeMaxEdit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end






function init_dialog(hObject, eventdata, handles, varargin)


set(handles.RescaleToggle,'Value',1);
handles.rescale = 1;

guidata(hObject, handles);

set(handles.PixelsizeEdit,     'String',sprintf('%g',handles.pixelsize));
%set(handles.InterpCellNumberEdit, 'String',handles.colormap);

set(handles.RescaleToggle,'Min',0);
set(handles.RescaleToggle,'Max',1);


% --- Executes on button press in RescaleToggle.
function RescaleToggle_Callback(hObject, eventdata, handles)
% hObject    handle to RescaleToggle (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of RescaleToggle

if get(hObject,'Value') == 0
    handles.rescale = 0;
else
    handles.rescale = 1;
end;

guidata(hObject, handles);

    
    
    
    